package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````618``#0```"(`0$```0`!30`(``)
M`"@`&P`:``$``'"`>P``@'L``(![```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````",>P``C'L```4```````$`
M`0```,#]``#`_0$`P/T!`(`"``"4`@``!@```````0`"````R/T``,C]`0#(
M_0$`"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DP/T`
M`,#]`0#`_0$`0`(``$`"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`N_`'V3K-(J9[FM8D>F[;.+V6B/8$
M````$`````$```!'3E4```````,````"`````````!$```!+````"`````@`
M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PX@!)!B@``"$L```!,````3P``
M`%,```!4````7````%T```!>`````````&````!A````8@```&,```!D````
M9P```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_Y`[9
M<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/NA;&!K"4/69Z_,9D)%
MU>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ&IY0O]I7&Z/@^TD`````````
M`````````````````*`1`````````P`+``````````(```````,`%@#5`@``
M```````````2````^P``````````````$@```%P"`````````````!(```".
M`@`````````````2````E@``````````````$@```'0!`````````````!(`
M```1`0`````````````2`````0``````````````(````+$!````````````
M`!(```!"`0`````````````2````,@$`````````````$@````,"````````
M`````!(````D`0`````````````2````?@(`````````````$@```!``````
M`````````"````"2`0`````````````2````$@(`````````````$@`````!
M`````````````!(```"L`0`````````````2````S@(`````````````$@``
M`"P``````````````"````"'`@`````````````2````1@``````````````
M$@```&,``````````````!8```!D`0`````````````2````=@``````````
M````$@```-,``````````````!(```"'```````````````2````/`(`````
M````````$@```/4!`````````````!(```!W`@`````````````2````MP,`
M````````````$@```+<``````````````!(```#=`@`````````````1````
M[@$`````````````$@```/<"`````````````!$````I`@`````````````2
M````-@(`````````````$@```%8!`````````````!(````@`@``````````
M```2````Y```````````````$@```$,"`````````````!(````%`0``````
M```````2````E@(`````````````$@```(L!`````````````!(```"]`@``
M```````````2````V0$`````````````$@```/P!`````````````!(````P
M`@`````````````2````A@(`````````````$@```+\!`````````````!(`
M``#E`@`````````````2````W`(`````````````(0```*(`````````````
M`!(```"X`0`````````````2````?P$`````````````$@```+0"````````
M`````!(```#;`@`````````````1````<`(`````````````$0```,8`````
M`````````!$```!2`@`````````````2````8@(`````````````$@````H"
M`````````````!(```!+`0`````````````2````2@(`````````````$@``
M`%0``````````````!(```#'`0`````````````2````&0(`````````````
M$@```.<!`````````````!(```"O`@`````````````2````G@(`````````
M````$@```)T!`````````````"(````2!```5``"```````0`!<`P`,``!4L
M``#<````$@`-`#<$``"9)```J`4``!(`#0#4`0``H10``+@!```2``T`-P,`
M`,T<```$````$@`-`%4#``!!*@``U`$``!(`#0#H`P``0``"```````0`!<`
M700``-$<``"@`0``$@`-`!T$``!```(``````!``%P!(`P``<1X``!@````2
M``T`:P,``#$C``!X````$@`-`,P#```P.0``!````!$`#P#V`P``B3<``-0`
M```2``T``00``.D;```\````$@`-``D$``!4``(``````!``%P`R!```5``"
M```````0`!<`2P0``+DC``#@````$@`-`-L#``````(``````!``%@"/`P``
MB1X```P!```2``T`1`0``$```@``````$``6`&H$```\``(`!````!$`%@#A
M`P``618````````2``T`*00``!4W``!T````$@`-`-T#``````(``````"``
M%@"E`P``J2,``!`````2``T`>0,``"4<``"H````$@`-`)L#``!=.```O```
M`!(`#0`1!```5``"```````0`!<`=`0``)4?``"<`P``$@`-``!?7V=M;VY?
M<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I
M<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S
M`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?
M<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!E<FQ?
M8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?
M871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P
M97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M7U]C>&%?9FEN86QI>F4`<F5A9`!S=')C:'(`9V5T<&ED`&UE;6UO=F4`7U]L
M:6)C7W-T87)T7VUA:6X`7U]F<')I;G1F7V-H:P!S=')C;7``;W!E;C8T`'5N
M;&EN:P!S=')T;VL`;65M<V5T`'-T<FYC;7``9V5T=6ED`&UE;6-H<@!C;&]S
M961I<@!S=')S='(`<FUD:7(`8VQO<V4`<W1R;&5N`'-T<F1U<`!R96%L;&]C
M`')E861D:7(V-`!A8F]R=`!?7W-P<FEN=&9?8VAK`'-T9&5R<@!M96UC<'D`
M<W1R<F-H<@!L<W1A=#8T`&]P96YD:7(`;'-E96LV-`!?7V5R<FYO7VQO8V%T
M:6]N`&5X:70`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9F%I;`!A8V-E<W,`;6MD
M:7(`7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U
M87)D`&QI8G!E<FPN<V\N-2XS-@!L:6)C+G-O+C8`;&0M;&EN=7@M87)M:&8N
M<V\N,P!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA
M;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R
M=`!?7V)S<U]S=&%R=%]?`'-H85]U<&1A=&4`>'-?:6YI=`!?7V5N9%]?`%]?
M8G-S7V5N9%]?`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP
M9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?
M<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1TQ)0D-?,BXS-`!'3$E"
M0U\R+C,S```````````"``$``@`"``$``0`!``$``@`!``$``@`!``(``0`!
M``(``@`"``(``0`#``$``0`!``$``0`!``(``@`"``(``0`"``(`!``"``(`
M`0`"``$``@`!``(``@`"``(``@`"``,``@`"``(``0`"``$``@`"``(``0`"
M``(``@`!``(``0`%``(``@`"``(``@`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`(P,`
M`!`````@````%&EI#0``!`"!!`````````$``P`9`P``$`````````"TD98&
M```%`(L$```0````LY&6!@```P"6!```$````!1I:0T```(`@00```````#`
M_0$`%P```,3]`0`7````_/\!`!<````$``(`%P````P``@`7````$``"`!<`
M```8``(`%P```!P``@`7````(``"`!<````D``(`%P```"@``@`7````,``"
M`!<````T``(`%P```#P``@`7````S/\!`!4)``#0_P$`%0H``-3_`0`5$0``
MV/\!`!47``#<_P$`$QH``.#_`0`5&P``Y/\!`!4<``#H_P$`%20``.S_`0`5
M)@``\/\!`!4]``#T_P$`%3X``/C_`0`52@``W/X!`!8#``#@_@$`%@0``.3^
M`0`6!0``Z/X!`!8&``#L_@$`%@<``/#^`0`6"```]/X!`!8*``#X_@$`%@L`
M`/S^`0`6#````/\!`!8-```$_P$`%@X```C_`0`6#P``#/\!`!80```0_P$`
M%A(``!3_`0`6$P``&/\!`!84```<_P$`%A4``"#_`0`6%@``)/\!`!88```H
M_P$`%AD``"S_`0`6'0``,/\!`!8>```T_P$`%A\``#C_`0`6(```//\!`!8A
M``!`_P$`%B(``$3_`0`6(P``2/\!`!8E``!,_P$`%B<``%#_`0`6*```5/\!
M`!8I``!8_P$`%BH``%S_`0`6*P``8/\!`!8L``!D_P$`%BT``&C_`0`6+@``
M;/\!`!8O``!P_P$`%C```'3_`0`6,0``>/\!`!8R``!\_P$`%C,``(#_`0`6
M-```A/\!`!8U``"(_P$`%C8``(S_`0`6.```D/\!`!8Y``"4_P$`%CH``)C_
M`0`6.P``G/\!`!8_``"@_P$`%D```*3_`0`600``J/\!`!9"``"L_P$`%D,`
M`+#_`0`61```M/\!`!9%``"X_P$`%D8``+S_`0`61P``P/\!`!9(``#$_P$`
M%DD``,C_`0`62@``"$`MZ3@!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y13M`0``
MQH_B'LJ,XA3]O.4`QH_B'LJ,X@S]O.4`QH_B'LJ,X@3]O.4`QH_B'LJ,XOS\
MO.4`QH_B'LJ,XO3\O.4`QH_B'LJ,XNS\O.4`QH_B'LJ,XN3\O.4`QH_B'LJ,
MXMS\O.4`QH_B'LJ,XM3\O.4`QH_B'LJ,XLS\O.4`QH_B'LJ,XL3\O.4`QH_B
M'LJ,XKS\O.4`QH_B'LJ,XK3\O.4`QH_B'LJ,XJS\O.4`QH_B'LJ,XJ3\O.5X
M1_WG`,:/XA[*C.*8_+SE`,:/XA[*C.*0_+SE`,:/XA[*C.*(_+SE`,:/XA[*
MC.*`_+SE`,:/XA[*C.)X_+SE`,:/XA[*C.)P_+SE`,:/XA[*C.)H_+SE`,:/
MXA[*C.)@_+SE`,:/XA[*C.)8_+SE`,:/XA[*C.)0_+SE`,:/XA[*C.)(_+SE
M`,:/XA[*C.)`_+SE`,:/XA[*C.(X_+SE`,:/XA[*C.(P_+SE`,:/XA[*C.(H
M_+SE`,:/XA[*C.(@_+SE`,:/XA[*C.(8_+SE`,:/XA[*C.(0_+SE>$?]YP#&
MC^(>RHSB!/R\Y0#&C^(>RHSB_/N\Y0#&C^(>RHSB]/N\Y0#&C^(>RHSB[/N\
MY0#&C^(>RHSBY/N\Y0#&C^(>RHSBW/N\Y0#&C^(>RHSBU/N\Y0#&C^(>RHSB
MS/N\Y0#&C^(>RHSBQ/N\Y0#&C^(>RHSBO/N\Y7A'_><`QH_B'LJ,XK#[O.4`
MQH_B'LJ,XJC[O.4`QH_B'LJ,XJ#[O.4`QH_B'LJ,XIC[O.4`QH_B'LJ,XI#[
MO.4`QH_B'LJ,XHC[O.4`QH_B'LJ,XH#[O.4`QH_B'LJ,XGC[O.5X1_WG`,:/
MXA[*C.)L^[SE`,:/XA[*C.)D^[SE`,:/XA[*C.)<^[SE`,:/XA[*C.)4^[SE
M`,:/XA[*C.),^[SE`,:/XA[*C.)$^[SE`,:/XA[*C.(\^[SE`,:/XA[*C.(T
M^[SE`,:/XA[*C.(L^[SE<+5;38JP6TM]1%M,S>D&$`>H!9(&J06J?$3K6!MH
M"9-/\``#__?"[U1*54NB6`.2$4;C6`23&$8"\![Z44OC6!QX`"QBT!WN<"]'
M2P>=>T0;:"@=`S6P\8!/TEB2^,8S0_`#`X+XQC-TTH``__=R[T5*!IP#1GI$
M1$EY1%!@(F@:8$-*!YAZ1-I@0DH!*`EH>D298%I@7]TA'03K@`X#\0P,4?@$
M2TSX!$^.1?G1`S`Y3@`A`)$J1GY$0_@@$#=)\&AY1/_W2NX$1H"S-$T(KGU$
MZ&C_]]KN,D@Q1GA$`/#I^$BS,$M[1-AH__<@[O_WC.XN2A]+>D336!IH"9M:
M0$_P``,MT2!&"K!PO?_W5NXG2GI$T&`(L__W@NX32QWN<"][1!MHTUB#^'M'
MC>?P:/_W)NX$1LGGJ&@0L0'P&OO0YQQ(,49X1`#PM/BH8``HR-#SY__WINX$
M(*GG`2#_]S[O__?`[@"_ZNH!`!;J`0`DZ@$`'`$``!3J`0#\````%`$``"0!
M```JZP$`'NL!`)8G``"()P``Z.H!`!<&``#0Z@$`""4``+KJ`0`VZ0$`CNH!
M`#HD``!/\``+3_``#@*\:D8$M`&TW_@8H`6CFD1/\``#"+0$2%KX``#_]^SN
M__>J[4SH`0`L`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!U_[_ZC3H`0``
M`0``!D@'2P=*>$1[1'I$@T(#T`5+TU@#L1A'<$<`OX;I`0"$Z0$`$N@!``0!
M```(2`E+>$0)2GM$&QIZ1-D/`>NC`4D0`]`%2]-8`[$81W!'`+]<Z0$`6.D!
M`.3G`0`(`0``"+4*2PI*>T1Z1!MX:[D)2]-8([$(2WM$&&C_][3N__>__P9+
M`2)[1!IP"+TFZ0$`M.<!`"@!``#:Z`$`!ND!`,3G`+\MZ?A#@$8?2WM$`"@V
MT!Y*FUC3^`"0N?$`#S'0!7@/1@`M&+\]+12_`24`)1/1V?@`0&RQ3D8@1BI&
M04;_]TCN$+EC73TK$-!6^`1/`"SRT2!&O>CX@P5&%?@!/P`K&+\]*_G1I>L(
M!>'GINL)!@$U+$2V$#Y@($:]Z/B#!$;GYTQ&Y>=PYP$`&`$``!=*&$MZ1!"U
M!$:<L--8:48;:!N33_```__WW.V@N02;`_1P0[/U($\8O[/U@$\-T`U*#$MZ
M1--8&F@;FUI`3_```PO1'+`0O0`@\><"(2!&__<N[;#Z@/!`">GG__>B[>CF
M`0`<`0``N.8!`#9*-TMZ1/"UG[#36!MH'9-/\``#$+$#>`1&6[DQ2C!+>D33
M6!IH'9M:0$_P``-3T1^P\+W_][#L!48`*.[0*$;_][[M`"@VT,-\`/$3!BXK
M`M%S>``K\M##?"XK,M`@1O_W#NT'1C!&__<*[3A$`C#_]USM'$L'1D_P_S)[
M1`$A`98`E/_WHNT"J3A&__?@[`$P.$8%T`:;`_1P0[/U@$\7T/_W].PX1O_W
MP.PH1O_WB.T`*,C1*$;_]QCM($;_]T[MJ^=S>"XKR=&S>``KMM#%Y__WE?_F
MY__W+NU\Y@$`'`$``&#F`0#X(```+>GP00]&+$DL2ZWU@%UY1(*P!D8-]8!0
M!#`-\00(RUA`]O]R048;:`-@3_```R1(>$3_]TKM!!X'W0*M8QX%ZP,,'/@$
M+.JYV[D92QWN<`\Z1C%&>T0;:,!8__=8[!E*#?6`415+!#%Z1--8&F@+:%I`
M3_```QC1#?6`70*PO>CP@1Q&(D8O(4!&__=0[0`HV]`(2!WN<%\C1D)&>$0`
M:#%&*%C_]X[LV>?_]]#L`+],Y@$`!.8!`(;E`0`<`0``8"```"SE`0!82EE+
M>D0MZ?!'#$:"L`5&TUC?^%B!&V@!DT_P``,+>/A$/2L(OP$T($;_]U#L:48&
M1BA&__>._H%&`"A4T/_W1NR&0D?92DL`GUCX`X"_`"MX`"L8OSTK%+\!(P`C
M!]`K1A/X`2\`*AB_/2KYT5L;L!S8^`!@&$3_]W[L\%'HL=CX`#`H1ME9$/@!
M.PMP`"L8OSTK"=!*'!#X`3L11@+X`3L]*QB_`"OVT0I&/2,+<!3X`3L"^`$_
M`"OYT2U**DMZ1--8&F@!FUI`3_```T;1`K"]Z/"'"?'_.13X`3L)^`$_`"OY
MT>GG(4M8^`.`V/@`<#MH@[,[1E/X!"])1@GQ`0D`*OC1`S&)`!M*>D03:+NY
M"$8!(Q-@__<N[()&`"C,T#E&3^J)!SI&__=*[,CX`*#-^`"0"?$!"0`C2O@I
M,(;G.$;_]WSL@D;(^````"BTT$_JB0?LYYE&""'5Y__W$NP`O\CD`0`<`0``
MK.0!`!@!```,Y`$`-.4!`#"U'>YP3Q)*#TF%L!%(>D1Y1`EH$$L`)7M$$EA@
M6`])`Y)Y1/_W2.P(20U+>40):`Q*>T1Z1&!8"TD!E7E$`)/_]WKK!;`PO4SD
M`0`PY`$`0N,!`!`!``!,7P``.AX```8A``"-#@``/!X```I*@K`*21WN<,]Z
M1`9("4MX1`!H4EA[1`=)7/@``'E$`9("L/_W$+S@XP$`VN(!`!`!``#B7@``
MTAT``"1*<+4D2WI$K?4`78:P#?4`40.LTU@4,0WU@%8;:`M@3_```__WSNL<
M24'R`0(<2Q`V>43-Z0`!>T0!(2!&__?:ZR!&3_2`4C%&__?(ZP0>'MM@'/_W
M?NL%1LBQ(D8Q1O_W+NL`(RM5#DH-]0!1"DL4,7I$TU@::`MH6D!/\``#!-$H
M1@WU`%T&L'"]__=HZP`EZ>>BX@$`'`$``,(=``"P'0``-N(!`/_WJK];2BWI
M\$\&1EI+>D2M]81=@;!92`WU@U4-\1`(TU@,1GA$048<-1MH*V!/\``#__<I
M_2\A!48P1O_WA.K`L4](,49X1/_W=/XP1DU*#?6#44A+'#%Z1--8&F@+:%I`
M3_```T#P@X`-]81=`;"]Z/"/($;_]PCK0TEY1/_W*.L$1@`HW-`C>`WQ@`K?
M^/R0JO$$!_E$`"M(T"6Q(48H1O_W@.NXLR!&__>JZD,>(T2#1IQ"/K\C&``A
M8!P#TPK@F$(9<`/0$_@!+2\J^-`@1O_WENJ#1C!&__>2ZEA$`3"P]8!?K-(I
M2`$A2T9/](!2>$0`E,WI`08X1O_W)NM!1CA&__=DZC"Y6OA@/`/T<$.S]0!/
M%]`>20`@>43_]]CJ!$8`*(S0(W@`*[;1U;$K>"XK!-`83$_P`0M\1,OG:W@`
M*^C0]N<!(3A&__<ZZ@`HX=$12#E&>$3_]^O].$;_]Y+J<^<.3$_P`0M\1+/G
M__>BZO+A`0`<`0``,!T``!H=``"HX0$`]!P``-X<``"*'```5!P``!0<```(
M'```Y!L``!"U+R$$1O_W[.D`L40<($:]Z!!`__=DNCM*\+4[2WI$K?6`78.P
M#?6`4=-8!#$;:`M@3_```P`H/-`#>`5&`"LXT/_W#.I"'`1&LO6`7T?8`:\I
M1CA&__<.ZF,>.T2?0@O2.!D-\04"`"$"X)!"`7`#T!#X`3TO*_C0+R$X1O_W
ML.EXL[A"A+\`(P-P.$;_]RKJ'TH-]8!1'$L$,7I$TU@::`MH6D!/\``#*]$-
M]8!=`[#PO1=*#?6`411+!#%Z1--8&F@+:%I`3_```QK1$DAX1`WU@%T#L+WH
M\$#_]P"Z`"#6YPU*#?6`40A+!#%Z1--8&F@+:%I`3_```P+1"$AX1.;G__<&
MZC[@`0`<`0``P-\!`)[?`0#<&@``;M\!`*P:``#,2LU+>D1PM<Q.@K#,3=-8
M?D1L1GU$&V@!DT_P``,A1C!&__?-^["QQDL`F.M8&6@!ZX`#6FA!^"`@`"KO
MT`0S6FA#^`0K`"KZT2%&,$;_][?[`"CHT;Q.?D0A1C!&__>O^["QMTL`F.M8
M&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]YG[`"CHT:Y.?D0A
M1C!&__>1^["QJ$L`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&
M,$;_]WO[`"CHT:!.?D0A1C!&__=S^["QF4L`F.M8&6@!ZX`#6FA!^"`@`"KO
MT`0S6FA#^`0K`"KZT2%&,$;_]UW[`"CHT9).?D0A1C!&__=5^["QBDL`F.M8
M&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]S_[`"CHT81.?D0A
M1C!&__<W^["Q>TL`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&
M,$;_]R'[`"CHT79.?D0A1C!&__<9^["Q;$L`F.M8&6@!ZX`#6FA!^"`@`"KO
MT`0S6FA#^`0K`"KZT2%&,$;_]P/[`"CHT6A.?D0A1C!&__?[^K"Q74L`F.M8
M&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]^7Z`"CHT5I.?D0A
M1C!&__?=^K"Q3DL`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&
M,$;_]\?Z`"CHT4Q.?D0A1C!&__>_^K"Q/TL`F.M8&6@!ZX`#6FA!^"`@`"KO
MT`0S6FA#^`0K`"KZT2%&,$;_]ZGZ`"CHT3Y.?D0A1C!&__>A^K"Q,$L`F.M8
M&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]XOZ`"CHT3!((49X
M1/_WA/H!1ABQ+4AX1/_WU/LL2"%&>$3_]WGZ`488L2I(>$3_]\G[*4@A1GA$
M__=N^@%&L+$F2'A$__>^^R5*$4MZ1--8&F@!FUI`3_```Q71(4DB2'E$>$0"
ML+WH<$#_]ZN['T@A1GA$__=0^@%&`"CDT!Q(>$3_]Y_[W^?_]U[H--\!`!P!
M``"H&@``)-\!`!@!``!L&@``.!H```@:``#4&0``J!D```@9```\&0``#!D`
M`-P8```D&```;A@``$H8``!L&```=!@``'88``"B%P``1-P!`'`8``#6%P``
M2A@``-07```72QA)&$I[1'E$`+48:(.PBEA#'!)H`9)/\``"#-`32A%+>D33
M6!IH`9M:0$_P``,3T0.P7?@$^PU(:49X1/_W\?DPL0!X,"@8OP`H%+\!(``@
M"$M[1!A@X>?^]_SO`+_.W`$`E-L!`!P!``!ZVP$`)!<``(#<`0`(M?[W7N_^
M]Z#O`+$`:`B]+DHO2WI$\+4N3H>P!4;36'Y$!*DP1AMH!9-/\``#__>]^1"Q
M`W@$1HNY)THD2WI$TU@::`6;6D!/\``#/-$C2"E&>$0'L+WH\$#_]_VZ*4;^
M]X3O6+$>2AE+>D336!IH!9M:0$_P``,FT0>P\+TH1O[W4.\'1B!&_O=,[SA$
M`C#^]Y[O$TL42@$A>T0"E'I$`)4!DD_P_S($1O[WXN\/2@=+>D336!IH!9M:
M0$_P``,$OR%&,$;%T/[WB.\0VP$`'`$``$@7``#FV@$`%A<``+K:`0#^%0``
M]A4``'+:`0`MZ?!/!T;?^`P%W_@,1:WU`$W?^`@5>$2_L'Q$/JXB':;Q=`,-
M]0!%05@$\1`.IO%<#"@T"6C%^/003_```:;Q:`D'RH/H!P#T-;[H#P"LZ`\`
MW_C,A*;QX`7X1)[H`P",Z`,`E.@'`(GH!P#?^+0$*49X1/_W(OD@L0-X!$8`
M*T#P8X'^]Z3N_O?F[@`H`/`W@=#X`*"Z\0`/`/`Q@5!&_O?([D```3#^]QKO
MFO@`,`1&@49[L=_X<+3[1"!&`)-/\/\R6T8!(0(T_O=:[QKX`3\`*_+1W_A4
M!*;Q7`IX1`+@6O@$#XBQ*4;_]^?X!$8`*/;0`W@`*_/0__<E^0`H[]`@1O[W
MVNX$1IBYIO%T"EKX!$MTL2-X`"L`\.^`($;_]Q+Y`"CST"!&_O?([@1&`"CM
MT"!&_O=^[H)&2$;^]WKN@D0*\@1*4$;^]\KN^$N#1D_P_S)[1`*3]DL!(<WX
M#)![1`&3]$L`E'M$_O<([T_TX'%81O[WV.T!,`71_O<X[P%H$2E`\-.`*498
M1O[WQNZ!1@BSZ4D[:.E*6/@!`'I$S?@`L`$A`&C^]Z;N3_``".1*#?4`0=A+
M]#%Z1--8&F@+:%I`3_```T#PH(%`1@WU`$T_L+WH\(]6^-`\`_1P0[/U@$_6
MT5;XR$S^]_#MA$+0T5;XT#S#\P@#L_7@?\G14$;^]VSN@$;/2"E&>$3_]U3X
M`48`*`#P-($X:/_W"_N"1@`H`/`M@5!&_O<"[@1&`R@/V<5)!#A01'E$_O?,
M[D"Y!"P`\""!5$04^`4\+RL`\!J!ODQ\1"-H6AP`\):``"L`\*:`NDF[2'E$
MNT]X1+M.__=X^;I-_O=J[KI+3_#_,@$A>T0#D[A+?T3-^`"P?D1[1,WI`3"U
M2T!&?41[1/[W;NX5X/[WHNX#:!$K&-'^]T[N"?$!"81&.T8B1@$A0$;-Z0.6
MS>D!7,WX`+#^]U;N3_3@<4!&_O<F[01&0QSAT%A&_O=\[:)(049X1/_W.OE`
M1O_W$_Y:YQQ&&>>F\6@$5/@$"P`H-M`I1O[WU?\`*/;0`W@`*_/0_O?.[8)&
M`"CNT/[WANU```$PN^:"2CMH6/@"`,WI`+$!(8Y*`&AZ1/[WV.TQY__WZ?V+
M2G)+#?4`07I$]#'36!IH"VA:0$_P``-`\-*`($8-]0!-/["]Z/!/_O>?O=_X
M!*(-(/[WKNU3(P1&^D2!1I/F?4@I1GA$_O>2_P`H`/"*@`-X`"L8OS`K%+\!
M(P`C(V``*W_T6J]01@`A_O=:[01&`"@_]%*O3_#_,V_P$0(")S4?`)?^]X#M
M!B(I1B!&_O<&[1;X!#P;N1;X`SQ#*V/0`",`(@"3($8`(_[W;.T`\#[_!T8#
MX"E&.$8`\'+_3_0`0BE&($;^]^KL`A[SW-_X:)$@1J;Q,`K^]S#MIO%%!3E&
M^4141J;Q,0>F\40``/#"_Q7X`2\@1@"22T9/\/\R`2'^]Y;M`C2O0O+13$H!
M(<WX"*!`1GI$2DO-Z0"R`"(&^`@L>T1'2GI$`Y)/\/\R_O>`[2_GU_@`H,_F
M?&@`+#_TXJX@1O[WSNP#*'_VW*X^200X($1Y1/[WF.T`*`B_HD;1YB!@?N<6
M^`(\02N7T1;X`3Q#*Y/1,WA(*Y#1<WA%*XW13_#_,V_P.0(@1@"7_O?Z["E&
M*2(@1O[W@.PK2RQ)3_#_,GM$S>D"4RI+>41`1LWI`+%[1`$A_O<Z[>KF_O?N
M[`"_'MH!`%+;`0`<`0``VMD!`!85``#6%0``9A4``$X5``!.%```+A4``"`!
M``!(%0``>-@!`"X5```(%0``%-D!``@4``"($P``Z!0``(H5```2$P``EA4`
M`!P3``#$%```FA(``&H3``#>U@$``!,``&82``!@$@``3!$``.(2``"F$P``
MJ!(``"@3``"T$```4!(``&1)94IY1/"U6DN#L!WN<$^*6&Y&84@Q1A)H`9)/
M\``">T0;:'A$Y5B5^&@PA?AI,/[W</X0L0-X,2M\T/_WBOI-2WM$&VCE6%5)
M*$8#(P$B>43^]\SK!49PL0)I1TM[1!MH$6A/2N!8>D3^]\SK*VD9:(MH6P)K
MU$%)`R,!(GE$"6A@6$A)>43^][#K!49XL49(,49X1/[W/?X"1@`H3M`X2REI
M>T0;:`EHX%C^]ZKK-4L!(CY)>T0;:#Y/>41_1.58*$;^]W3K.TH!1BA&>D3^
M]YCK+4LY2``B>T0;:#%&>$3C6(/X:2#^]Q3^!$:X8+"Q3_3@<2!&_O="ZT(<
M`T81*!B_`2HLV"U*(TMZ1--8&F@!FUI`3_```R#1`[#PO7AH__>9_`1&N&``
M*.'1)4AX1/[W-.Q#>``KA=!^YR)+*FE[1!!H6V@9:/[WU?ZOYP]+>T0;:.!8
M_O?BZXSG_O?RZQI)(D8:2'E$>$1):`EH_O<4['C5`0!6U0$`.M4!`!K5`0#T
MU`$`XM0!`+[4`0!&U`$`B-0!`!P!```0$```D!$``'P1``!F$0``6`\``#01
M``!"U0$`.A$````/``"`TP$`X!```+[4`0"8U`$`RA```"]*,$MZ1/"U!4:#
ML--8&V@!DT_P``/_]RWY+R$$1O[W#NL`L40<*$\@1O[WBNLL'G]$&+\!)`9&
M.VA:'"S0`"L,OP`D!/`!!%RY($H=2WI$TU@::`&;6D!/\``#+M$#L/"]*W@`
M*_#0&4D$(C!&>43^]\[K`"CHT19*$DMZ1--8&F@!FUI`3_```Q?1*$8#L+WH
M\$#^]]"]#TAI1GA$_O=/_4BQ`W@`*QB_,"L4OP$C`",<0#M@Q^<X8,;G_O=8
MZ[32`0`<`0``P-,!`&K2`0"Z#@``/-(!`.`-```MZ?!/`T;?^!!*K?4K?0/Q
M@`??^`@Z?$0(J0`F`I`*1D`PO$;C6!MHJ9-/\``#4.D"=%9@UF`0,C^Z0O@0
M?",*)0(#]']#"#!#ZA1C!?1_!4/J!&-@14/J!0-"^`@\YM'=Z2*""JPFFPWQ
MB`D`DR2H)JT!]0)S`Y`@1@25S>D%00UHS?@<D)%&W?B4X-WXG,`)G]WX++`D
MGMWX**``F0&3`>"21IM&`)$`(]#I#A10^`@O0V=10('J"`&P1D-H:4``GE5&
M7$"$Z@D$\49\0.9&3^K1?$D83.I$#`&<0>H,`5]&3_``#(1"`6?:T0.;`IC=
MZ05!'6@$F]#I`7L;:`.3T.D#.D_JFP[0^`#`"F@A:$[J@WZ$:4?VF1/%]H(C
M`)0$:M(83^K<8`&40.I'$!(9`)Q`ZDP0W?@<D((8BNH$`$[JBWX`Z@L`W?@P
M@&!`V?@`8!(83^J<"8KJ#@#)&$GJAWD`Z@P`2>J,>0D9@.H*``Z?"!B.Z@D!
M&.L#"!%``.OR8!CK"@B!Z@X!3^JR`ACK`0'_&!?K#@@!Z_!GB>H"`=WX0.`!
M0$_JL`"!Z@D!&.L!`1[K`PX>ZPD)`>OW;H+J``'=^$B`.4!/ZK<'44`9ZP$!
M&.L#"!CK`@F`Z@<"W?A0@`+J#@(!Z_YA0D!/ZKX.&>L"`ACK`P@8ZP`)`NOQ
M8(?J#@+=^%B`"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX8(`"0$_J
ML`""Z@X"&>L"`ACK`P@8ZPX)`NOW;H'J``+=^&B`.D!/ZK<'2D`9ZP("&.L#
M"!CK`0D"Z_YA@.H'`MWX<(`"Z@X"3^J^#D)`&>L"`ACK`P@8ZP`)`NOQ8(?J
M#@+=^'B`"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX@(`"0$_JL`""
MZ@X"`YP9ZP("&.L#"!CK#@X"Z_=H@>H``CI`3^JW!TI`'NL"`O88=AB`Z@<!
M`>H(`0+K^&)!0$_JN`AQ&.T8+1@!Z_)@A^H(`1%`3^JR`HCJ`@9Y0&D8!D`H
MG>08`>OP88;J"`9/ZK``Y!FD&8+J``?M&`]`%>L(!BJ=!.OQ9%=`3^JQ`?89
M@.H!#NT8KQ@.Z@0.+)U/ZK0"CNH`#@;K]&87ZPX$@>H"!^T8-T`M&"Z83T`$
MZ_9D[QE/ZK8&PQ@PG5L8@NH&`2%`!^OT;E%`3^JT!%@83O:A,\;VV6,RF17K
M`P@`Z_Y@&.L""(;J!`*"Z@X"3^J^!1CK`@B$Z@4.RA@TGPCK\&&.Z@`.DAE/
MZK``$NL.`C:>_QB%Z@`.`NOQ8H[J`0X\&4_JL0$4ZPX$.)_V&(#J`0X$Z_)D
MCNH"#G493^JR`A7K#@4ZGH'J`@[_&([J!`X_&`7K]&`7ZPX'3^JT!!;K`PX\
MG1[K`0X'Z_!A@NH$!T=`3^JP`![K!P[O&#Z>OQ@.Z_%BA.H`#H[J`0Y/ZK$!
M%^L.!Q;K`PY`G1[K!`X'Z_)D@.H!!U=`3^JR`A[K!P[O&$*>/Q@.Z_1@@>H"
M#H[J!`Y/ZK0$%^L.!T2=@NH$#O88!^OP9X[J``YV&$_JL``6ZPX&1IF$Z@`.
M[1@&Z_=FCNH'#JT83^JW!Q7K#@5(FLD8@.H'#@7K]F6.Z@8.#!E/ZK8&%.L.
M!$J9TAB'Z@8.!.OU9([J!0X0&$_JM040ZPX`3)J&Z@4.R1@`Z_1@CNH$#LD9
M3^JT!!'K#@%.GX7J!`[2&`'K\&&.Z@`.DAE/ZK``$NL.`E">_QB$Z@`.`NOQ
M8H[J`0Y]&4_JL0$5ZPX%4I_V&(#J`0Z.Z@(.-!D4ZPX$!>OR9A?K`PY/ZK("
M5)T>ZP`.@>H"``3K]F1P0![K``Y/ZK8`[1B"Z@`&:1A6G69`#NOT;HD93^JT
M!.L86)V;&(#J!`*"Z@X"3^J^!YH82_;<0\CV&W,!Z_YA[1A$Z@<.6IXH&`[J
M`0X$Z@<%3NH%#@+K\6(0ZPX.3^JQ`?`87)T`&4?J`00.Z_)F%$`'Z@$.3^JR
M`D3J#@0!Z@(()!CM&$'J`@`5ZP<.,$`$Z_9E7IQ`Z@@`3^JV!A#K#@[@&`[K
M]61`&$+J!@$"Z@8.*4!@GT'J#@%/ZK4%"1@!Z_1@_QA&Z@4!!NH%#KH8(4!B
MGT_JM`1!Z@X!!>H$"(D8_QA%Z@0"%^L&#@)`9)\!Z_!A0NH(`D_JL``2ZPX"
M_Q@$Z@`.?1D"Z_%G1.H``F:>"D!/ZK$!0NH.`MWXH.%5&?(8$AE`Z@$$3^JW
M!@7K]V4\0`#J`0<\0T'J!@>B&![K`P0D&`'J!@YJF"]``NOU8D?J#@=/ZK4%
M/!E&Z@4'P!@$Z_)D!NH%#D`8%T!/ZK(!;)I'Z@X'/QA%Z@$`TA@@0)(9!^OT
M9@7J`0=/ZK0$.$-!Z@0'@!ANF@'J!`XW0-(8`.OV8%49<)I'Z@X'3^JV!G\9
MTAA5&`?K\&%$Z@8'!.H&#G*:!T!'Z@X'3^JP`'T9TA@2&4;J``0&Z@`'#$`\
M0P7K\66D&'2:3^JQ`03K]632&$#J`0<`Z@$.EADO0'::1^H.!T_JM06_&=(8
M%A@'Z_1@0>H%!P'J!0YXFB=`1^H.!T_JM`2_&47J!`;2&`9`4A@'Z_!A!>H$
M!T_JL``^0P*?MA@`(@3J``X&Z_%F>F#Z8'J:TAA5&0`B>F'Z843J``=\F@]`
M1^H.!T_JL0%_&=(80.H!!0?K]F<2ZP0.-4!/ZK8$?IH`Z@$&-4,!Z@0&%>L.
M!=,8&QA!Z@0`.$"`FC!#!>OW9<`83/+6$\SV8B-/ZK<'UAB"FG88A.H'`6E`
M`.OU8'883^JU!=(8A^H%`109A)I!0`;K\&9D&$_JL`#2&(7J``'7&8::!.OV
M9'%`?QA/ZK8&T1B(FDD9!^OT98#J!@=G0$_JM`3)&=<8/QB*FH;J!``!Z_5A
M:$!/ZK4%/QC0&(`9C)H'Z_%FA.H%!T]`3^JQ`<`9UQ@_&8Z:A>H!!`#K]F!T
M0#\93^JV!-88D)IV&0?K\&6!Z@0'1T!/ZK``]AG7&'\8DIH&Z_5AA.H`!FY`
M3^JU!;\9UA@V&92:!^OQ9(#J!0=/0$_JL0'V&=<8/QB6F@;K]&"%Z@$&9D!/
MZK0$OQG6&'89F)H'Z_!E@>H$!T=`3^JP`/89UQA_&)J:!NOU883J``9N0$_J
MM06_&=88-AF<F@?K\62`Z@4'3T!/ZK$!]AG7&#\8GIH&Z_1@A>H!!F9`3^JT
M!+\9UAAV&:":!^OP98'J!`='0$_JL`#V&=(85Q@&Z_5AHIJ$Z@`&;D!/ZK4%
MOQG2&!89!^OQ9(#J!0>DFD]`3^JQ`?<9`IX'Z_1GTA@0&`KKMP(R8:::A>H!
M!F9`3^JT!(`9TQB!Z@0"`.OW8'I`$^L,`P*?6QF;&!#K"P(#Z_!C`)@[8`&;
M)!BZ8`Q*R1@`(WMB"4MZ1+QA.6+36!IHJ9M:0$_P``,#T0WU*WV]Z/"/_?=`
M[@"_QM$!`!P!``#FQP$`"+6`(/WW+NZ?[0Y[`"*"9X#M`'N?[0U[@.T">Y_M
M#7N`[01[G^T->X#M!GN?[0U[@.T(>Y_M#7N`[0I[@.T,>PB]`+\!(T5G````
M`(FKS>\`````_MRZF`````!V5#(0`````/#ATL,````````````````MZ?A#
M!4861H!J`",,1O<7U>D,(0#KQ@R$1>AJ<^L```+2`3)!\0`!J&\%\3@(Q>D*
MPW,/0^K'`YL8*V-!ZU=Q:6.`NS\N0]VF\4`)3^J9%G<<!.N'%R%&0T8$\4`.
MT?@`P!`Q4?@,3!`S4?@(#%'X!"QQ14/X$,Q#^`Q,0_@(#$/X!"SKT0Q&*$;_
M]VWZO$+AT:GKAA8R1CE&0$;]]U[MKF>]Z/B#P/%`!R%&MT)`1*B_-T8Z1OWW
M4NVK;SM$JV=`*^[1*$;V&SQ$__=-^KGG)T;@YRWI\$$!\3@'#$:+:@5&#FN`
M(9/Z@_C#\\4#-KI:'+@8."KY5$3=PO%``@`A_??6["!&__<O^CA&."(`(?WW
MSNP@1L3I'&C_]R7ZXW@K<"!&8XAK<"-H&PJK<"-HZW#C>BMQ8XEK<:-H&PJK
M<:-HZW'C?"MR8XIK<B-I&PJK<B-IZW+C?BMS8XMK<Z-I&PJK<Z-IZW.4^",P
M*W1CC&MT(VH;"JMT(VKK=+WH\$']][2\PO$X`@`A_?>2[,'G`DM[1!MH_?=5
MO0"_YL8!``A`+>D(@+WH`0`"`#T```!`````"P```$`````0````0````"8`
M``!`````-0```$`````#````0`````8```!`````%````$`````.````0```
M``T```!`````)0```$`````2````0````"@```!``````@```$`````8````
M0`````D```!`````"@```$```````````````"5S+R5S````+W!R;V,O<V5L
M9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0````
M`%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````
M4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4`
M``!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%2
M7U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````
M,0```$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`
M````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@`````E
M<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U
M)7,`````&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].````
M`#$N,#4V````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!
M344`````5$5-4$1)4@!435``+W1M<`````!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)$-!0TA%7VUA<FME<BP@)&-A8VAE
M7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN
M(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H
M95]M87)K97(@/2`B7#!#04-(12(["B1C86-H95]N86UE7W-I>F4@/2`T,#L*
M?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU
M;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D
M9F@["FUY("1P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I>F4[("`@
M("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*
M=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D
M9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII
M9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2![
M"B1P;W,@*ST@)&D["G)E='5R;B`D<&]S.PI]"B1P;W,@+3T@)&-H=6YK7W-I
M>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@
M0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D
M=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE
M;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B
M.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*
M0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X
M92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_
M("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S
M*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP
M*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!]
M(ETI.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L
M("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O
M;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S
M(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC
M7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\
M(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-
M04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U
M=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`[
M"G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E
M="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R
M="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD9&%T85]P;W,@
M/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L
M(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S
M="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY
M("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F
M=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;
M82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@
M)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP
M;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E>'0B+"`D8G5F
M+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92![
M"B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C
M(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T
M>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`
M24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N
M(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U
M;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E
M("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@
M)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI
M.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^
M>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`
M24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&
M:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_
M)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*=6YL97-S
M("@D8G5F(&5Q(")02UPP,#-<,#`T(BD@>PIO=71S*'%Q6TYO('II<"!F;W5N
M9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL
M87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@
M("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM
M>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T
M92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@
M8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I
M<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*
M=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R
M"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H
M:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8[
M"GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?
M:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB
M<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H
M($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@
M(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?
M87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*
M96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF
M("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E
M<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@
M9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?
M;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES
M=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN
M8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]
M"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B
M73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T
M82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O
M+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@
M+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T
M(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H
M+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A
M=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*
M24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@
M8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?<&]S
M*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92!["FQO
M8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0II9B`H)&UE=&%?
M<&%R>V-L96%N?2D@>PIM>2`D<&%R7V-L96%N(#T@(CTQ(CL*;7D@)'!A<W-?
M<&%R7V-L96%N(#T@=6,@(E]?<&%S<U]P87)?8VQE86Y?7R(["B1L;V%D97(@
M/7X@<WLH/SP])'MP87-S7W!A<E]C;&5A;GTI*"`K*7T*>R1P87)?8VQE86X@
M+B`H(B`B('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'!A<E]C;&5A;BDI*7UE
M9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q
M=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@
M9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I
M(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO
M*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S
M>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A
M;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?
M97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R
M:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM
M>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H
M)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2![
M"FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D
M;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L
M;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A
M8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0[
M"GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I
M<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D
M("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R
M968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U
M=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL
M92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@
M*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS
M92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D
M9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT
M96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI
M)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*
M<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E
M<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA
M;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T
M(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@
M*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P
M87)T(&]F("(D;W5T(ET["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["FEF("@A)&-A8VAE7VYA;64@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@
M1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D=&@L("(\.G)A=R(L("1O
M=70["B1C='@M/F%D9&9I;&4H)'1H*3L*8VQO<V4@)'1H.PHD8V%C:&5?;F%M
M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@
M*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C
M:&5?;F%M92`N/2`D8V%C:&5?;6%R:V5R.PIM>2`D;V9F<V5T(#T@)&9H+3YT
M96QL("L@;&5N9W1H*"1C86-H95]N86UE*2`M(&QE;F=T:"@D;&]A9&5R*3L*
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*<&%C:R@G3B<L("1O9F9S970I+`HD
M4$%27TU!1TE#*0HF)B`D9F@M/F-L;W-E"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E
M<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G
M<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV
M93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,
M:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX
M.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O
M;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=
M*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL
M94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E
M<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@
M(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C
M+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]
M($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D
M<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE
M+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ
M;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S
M('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L
M:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U
M:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR
M97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R
M;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<[
M"G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR
M97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L
M('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R
M96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2
M(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M
M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P
M871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V
M86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*
M:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE
M(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED
M*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@
M)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM
M>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A
M8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@
M(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R
M;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T[
M"FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X]
M(#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ
M90HM(&QE;F=T:"@D8V%C:&5?;6%R:V5R*2P@,#L*;7D@)&)U9CL*<F5A9"`D
M9F@L("1B=68L(&QE;F=T:"@D8V%C:&5?;6%R:V5R*3L*:68@*"1B=68@97$@
M)&-A8VAE7VUA<FME<BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%
M7V]F9G-E=%]S:7IE"BT@;&5N9W1H*"1C86-H95]M87)K97(I"BT@)&-A8VAE
M7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I
M>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F
M(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M
M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]
M"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE
M+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A
M<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E
M;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G
M/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF
M)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N
M86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@
M)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK
M*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P
M<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D
M,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD
M(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US
M("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G
M;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL*
M*"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[
M7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO
M)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB
M4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@
M+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I
M9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@````!P97)L>'-I+F,````]````0`````L```!`````$````$`````F````
M0````#4```!``````P```$`````&````0````!0```!`````#@```$`````-
M````0````"4```!`````$@```$`````H````0`````(```!`````&````$``
M```)````0`````H```!```````````````#8FO]_`0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````%$7```1%P```0````D#```!````
M&0,```$````C`P``#````*`1```-````*#D``!D```#`_0$`&P````0````:
M````Q/T!`!P````$````]?[_;[0!```%````'`D```8```"<`@``"@```*$$
M```+````$````!4``````````P```-#^`0`"````X`$``!0````1````%P``
M`,`/```1````\`X``!(```#0````$P````@````>````"````/O__V\!```(
M_O__;Y`.``#___]O`@```/#__V^^#0``^O__;PX`````````````````````
M````````````````````````````````````R/T!````````````K!$``*P1
M``"L$0``K!$``*P1``"L$0``K!$``*P1``"L$0``K!$``*P1``"L$0``K!$`
M`*P1``"L$0``K!$``*P1``"L$0``K!$``*P1``"L$0``K!$``*P1``"L$0``
MK!$``*P1``"L$0``K!$``*P1``"L$0``K!$``*P1``"L$0``K!$``*P1``"L
M$0``K!$``*P1``"L$0``K!$``*P1``"L$0``K!$``*P1``"L$0``K!$``*P1
M``"L$0``K!$``*P1``"L$0``K!$``*P1``"L$0``K!$``*P1``"L$0``K!$`
M`*P1``"L$0``````````````````````````````````````````````````
M````````````````H10````````$``(`_____^0\```@.@```````.`Z``#D
M.@``V#P``"@Z``#@/````````,0\``#,/````````.P\``!'0T,Z("A$96)I
M86X@,3(N,BXP+34I(#$R+C(N,`!!,@```&%E86)I``$H````!3<M00`&"@=!
M"`$)`@H$$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-
M+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S
M``````````````````````````````````````````````````````````L`
M```!`````@```%0!``!4`0``&0```````````````0`````````3````!P``
M``(```!P`0``<`$``"0```````````````0`````````)@````<````"````
ME`$``)0!```@```````````````$`````````#0```#V__]O`@```+0!``"T
M`0``Z`````4`````````!`````0````^````"P````(```"<`@``G`(``(`&
M```&`````P````0````0````1@````,````"````'`D``!P)``"A!```````
M```````!`````````$X```#___]O`@```+X-``"^#0``T`````4`````````
M`@````(```!;````_O__;P(```"0#@``D`X``&`````&`````@````0`````
M````:@````D````"````\`X``/`.``#0````!0`````````$````"````',`
M```)````0@```,`/``#`#P``X`$```4````5````!`````@```!\`````0``
M``8```"@$0``H!$```P```````````````0`````````=P````$````&````
MK!$``*P1``#T`@`````````````$````!````((````!````!@```*`4``"@
M%```B"0`````````````"`````````"(`````0````8````H.0``*#D```@`
M``````````````0`````````C@````$````"````,#D``#`Y``!00@``````
M```````$`````````)8````!``!P@@```(![``"`>P``"`````T`````````
M!`````````"A`````0````(```"(>P``B'L```0```````````````0`````
M````JP````X````#````P/T!`,#]```$```````````````$````!````+<`
M```/`````P```,3]`0#$_0``!```````````````!`````0```##````!@``
M``,```#(_0$`R/T```@!```&``````````0````(````S`````$````#````
MT/X!`-#^```P`0`````````````$````!````-$````!`````P```````@``
M``$`0```````````````!`````````#7````"`````,```!```(`0``!`!0`
M``````````````0`````````W`````$````P`````````$```0`>````````
M```````!`````0```.4````#``!P``````````!>``$`,P``````````````
M`0`````````!`````P``````````````D0`!`/4```````````````$`````
#````
